==> 0.0.3.tar.gz: lib/src/dummyAPI/metricCreation.dart <==
import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'dart:io';
import 'dart:convert';
import '../variables.dart';


Future createMetricData() async{

 await createSensorData();

 await createUserData('lib/src/dummyAPI/dummydata/metric/CSMG.json');
 await createUserData('lib/src/dummyAPI/dummydata/metric/GDPR.json');
 await createUserData('lib/src/dummyAPI/dummydata/metric/Harvest.json');

 await createDeviceData('lib/src/dummyAPI/dummydata/metric/KMS.json');
 await createDeviceData('lib/src/dummyAPI/dummydata/metric/IDS.json');
 await createDeviceData('lib/src/dummyAPI/dummydata/metric/Fraud.json');

}


Future createSensorData() async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  Map x = json.decode(await File('lib/src/dummyAPI/dummydata/metric/RAE.json').readAsString());

  var t =  x.entries.iterator;

  while(t.moveNext()){

    var node = t.current.value;

    try {
      //storage.controller.add(NodeImpl(storage.userUUID!, ':Users'));
      storage.controller.add(NodeImpl(node['cUUID'], ':Users:' + storage.userUUID!));
      storage.controller.add(NodeImpl('data', ':Users:' + storage.userUUID! + ':' + node['cUUID']));
      storage.controller.add(NodeImpl('metrics', ':Users:' + storage.userUUID! + ':' + node['cUUID']+':data'));

    }
    // ignore: empty_catches
    catch(e){ }

    try{
      //  storage.controller.add(NodeImpl(storage.deviceUUID!, ':Devices'));
      storage.controller.add(NodeImpl(node['cUUID'], ':Devices:' + storage.deviceUUID!));
      storage.controller.add(NodeImpl('data', ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']));
      storage.controller.add(NodeImpl('metrics', ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']+':data'));

    }
    // ignore: empty_catches
    catch(e){}

    if (node['mUUID'] == '123e4567-e89b-42d3-adev-55664244atos-s05') {

      Node temp = NodeImpl(node['mUUID'], ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']+':data:metrics');
      temp.addValue(NodeValueImpl('name', node['name']));
      temp.addValue(NodeValueImpl('minValue', node['minValue']));
      temp.addValue(NodeValueImpl('maxValue', node['maxValue']));
      temp.addValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
      temp.addValue(NodeValueImpl('valueType', node['valueType']));
      temp.addValue(NodeValueImpl('flag', node['flag']));
      temp.addValue(NodeValueImpl('threatsImpact', node['threatsImpact']));

      storage.controller.add(temp);


    } else {

      Node temp = NodeImpl(node['mUUID'], ':Users:' + storage.userUUID! + ':' + node['cUUID']+':data:metrics');
      temp.addValue(NodeValueImpl('name', node['name']));
      temp.addValue(NodeValueImpl('minValue', node['minValue']));
      temp.addValue(NodeValueImpl('maxValue', node['maxValue']));
      temp.addValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
      temp.addValue(NodeValueImpl('valueType', node['valueType']));
      temp.addValue(NodeValueImpl('flag', node['flag']));
      temp.addValue(NodeValueImpl('threatsImpact', node['threatsImpact']));

      storage.controller.add(temp);
    }

  }

  //print(storage.controller.get(':Users:' + storage.userUUID! + ':' + companyUUID +':data:metrics').getChildren());
  //print(storage.controller.get(':Devices:' + storage.deviceUUID! + ':' + companyUUID +':data:metrics').getChildren());

}


Future createDeviceData(var path) async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  Map x = json.decode(await File(path).readAsString());

  var t =  x.entries.iterator;

  while(t.moveNext()){

    var node = t.current.value;

    try{
      //  storage.controller.add(NodeImpl(storage.deviceUUID!, ':Devices'));
      storage.controller.add(NodeImpl(node['cUUID'], ':Devices:' + storage.deviceUUID!));
      storage.controller.add(NodeImpl('data', ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']));
      storage.controller.add(NodeImpl('metrics', ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']+':data'));

    }
    // ignore: empty_catches
    catch(e){}

    Node temp = NodeImpl(node['mUUID'], ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']+':data:metrics');
    temp.addValue(NodeValueImpl('name', node['name']));
    temp.addValue(NodeValueImpl('minValue', node['minValue']));
    temp.addValue(NodeValueImpl('maxValue', node['maxValue']));
    temp.addValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
    temp.addValue(NodeValueImpl('valueType', node['valueType']));
    temp.addValue(NodeValueImpl('flag', node['flag']));
    temp.addValue(NodeValueImpl('threatsImpact', node['threatsImpact']));

    storage.controller.add(temp);

  }

  //print(storage.controller.get(':Devices:' + storage.deviceUUID! + ':' + companyUUID +':data:metrics').getChildren());

}



Future createUserData(var path) async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  Map x = json.decode(await File(path).readAsString());

  var t =  x.entries.iterator;

  while(t.moveNext()){

    var node = t.current.value;

    try {
      //storage.controller.add(NodeImpl(storage.userUUID!, ':Users'));
      storage.controller.add(NodeImpl(node['cUUID'], ':Users:' + storage.userUUID!));
      storage.controller.add(NodeImpl('data', ':Users:' + storage.userUUID! + ':' + node['cUUID']));
      storage.controller.add(NodeImpl('metrics', ':Users:' + storage.userUUID! + ':' + node['cUUID']+':data'));

    }
    // ignore: empty_catches
    catch(e){}

    Node temp = NodeImpl(node['mUUID'], ':Users:' + storage.userUUID! + ':' + node['cUUID']+':data:metrics');
    temp.addValue(NodeValueImpl('name', node['name']));
    temp.addValue(NodeValueImpl('minValue', node['minValue']));
    temp.addValue(NodeValueImpl('maxValue', node['maxValue']));
    temp.addValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
    temp.addValue(NodeValueImpl('valueType', node['valueType']));
    temp.addValue(NodeValueImpl('flag', node['flag']));
    temp.addValue(NodeValueImpl('threatsImpact', node['threatsImpact']));


    storage.controller.add(temp);


  }

 // print(storage.controller.get(':Users:' + storage.userUUID! + ':' + companyUUID +':data:metrics').getChildren());


}

==> 0.0.4.tar.gz: lib/src/dummyAPI/metricCreation.dart <==
import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'dart:io';
import 'dart:convert';
import '../variables.dart';


Future createMetricData() async{

 await createSensorData();

 await createUserData('indicator_pkg-0.0.4/src/dummyAPI/dummydata/metric/CSMG.json');
 await createUserData('indicator_pkg-0.0.4/src/dummyAPI/dummydata/metric/GDPR.json');
 await createUserData('indicator_pkg-0.0.4/src/dummyAPI/dummydata/metric/Harvest.json');

 await createDeviceData('indicator_pkg-0.0.4/src/dummyAPI/dummydata/metric/KMS.json');
 await createDeviceData('indicator_pkg-0.0.4/src/dummyAPI/dummydata/metric/IDS.json');
 await createDeviceData('indicator_pkg-0.0.4/src/dummyAPI/dummydata/metric/Fraud.json');

}


Future createSensorData() async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  Map x = json.decode(await File('indicator_pkg-0.0.4/src/dummyAPI/dummydata/metric/RAE.json').readAsString());

  var t =  x.entries.iterator;

  while(t.moveNext()){

    var node = t.current.value;

    try {
      //storage.controller.add(NodeImpl(storage.userUUID!, ':Users'));
      storage.controller.add(NodeImpl(node['cUUID'], ':Users:' + storage.userUUID!));
      storage.controller.add(NodeImpl('data', ':Users:' + storage.userUUID! + ':' + node['cUUID']));
      storage.controller.add(NodeImpl('metrics', ':Users:' + storage.userUUID! + ':' + node['cUUID']+':data'));

    }
    // ignore: empty_catches
    catch(e){ }

    try{
      //  storage.controller.add(NodeImpl(storage.deviceUUID!, ':Devices'));
      storage.controller.add(NodeImpl(node['cUUID'], ':Devices:' + storage.deviceUUID!));
      storage.controller.add(NodeImpl('data', ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']));
      storage.controller.add(NodeImpl('metrics', ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']+':data'));

    }
    // ignore: empty_catches
    catch(e){}

    if (node['mUUID'] == '123e4567-e89b-42d3-adev-55664244atos-s05') {

      Node temp = NodeImpl(node['mUUID'], ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']+':data:metrics');
      temp.addValue(NodeValueImpl('name', node['name']));
      temp.addValue(NodeValueImpl('minValue', node['minValue']));
      temp.addValue(NodeValueImpl('maxValue', node['maxValue']));
      temp.addValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
      temp.addValue(NodeValueImpl('valueType', node['valueType']));
      temp.addValue(NodeValueImpl('flag', node['flag']));
      temp.addValue(NodeValueImpl('threatsImpact', node['threatsImpact']));

      storage.controller.add(temp);


    } else {

      Node temp = NodeImpl(node['mUUID'], ':Users:' + storage.userUUID! + ':' + node['cUUID']+':data:metrics');
      temp.addValue(NodeValueImpl('name', node['name']));
      temp.addValue(NodeValueImpl('minValue', node['minValue']));
      temp.addValue(NodeValueImpl('maxValue', node['maxValue']));
      temp.addValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
      temp.addValue(NodeValueImpl('valueType', node['valueType']));
      temp.addValue(NodeValueImpl('flag', node['flag']));
      temp.addValue(NodeValueImpl('threatsImpact', node['threatsImpact']));

      storage.controller.add(temp);
    }

  }

  //print(storage.controller.get(':Users:' + storage.userUUID! + ':' + companyUUID +':data:metrics').getChildren());
  //print(storage.controller.get(':Devices:' + storage.deviceUUID! + ':' + companyUUID +':data:metrics').getChildren());

}


Future createDeviceData(var path) async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  Map x = json.decode(await File(path).readAsString());

  var t =  x.entries.iterator;

  while(t.moveNext()){

    var node = t.current.value;

    try{
      //  storage.controller.add(NodeImpl(storage.deviceUUID!, ':Devices'));
      storage.controller.add(NodeImpl(node['cUUID'], ':Devices:' + storage.deviceUUID!));
      storage.controller.add(NodeImpl('data', ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']));
      storage.controller.add(NodeImpl('metrics', ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']+':data'));

    }
    // ignore: empty_catches
    catch(e){}

    Node temp = NodeImpl(node['mUUID'], ':Devices:' + storage.deviceUUID! + ':' + node['cUUID']+':data:metrics');
    temp.addValue(NodeValueImpl('name', node['name']));
    temp.addValue(NodeValueImpl('minValue', node['minValue']));
    temp.addValue(NodeValueImpl('maxValue', node['maxValue']));
    temp.addValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
    temp.addValue(NodeValueImpl('valueType', node['valueType']));
    temp.addValue(NodeValueImpl('flag', node['flag']));
    temp.addValue(NodeValueImpl('threatsImpact', node['threatsImpact']));

    storage.controller.add(temp);

  }

  //print(storage.controller.get(':Devices:' + storage.deviceUUID! + ':' + companyUUID +':data:metrics').getChildren());

}



Future createUserData(var path) async{


  //create :Users:tool_iD:plugin_UUID:data node paths

  Map x = json.decode(await File(path).readAsString());

  var t =  x.entries.iterator;

  while(t.moveNext()){

    var node = t.current.value;

    try {
      //storage.controller.add(NodeImpl(storage.userUUID!, ':Users'));
      storage.controller.add(NodeImpl(node['cUUID'], ':Users:' + storage.userUUID!));
      storage.controller.add(NodeImpl('data', ':Users:' + storage.userUUID! + ':' + node['cUUID']));
      storage.controller.add(NodeImpl('metrics', ':Users:' + storage.userUUID! + ':' + node['cUUID']+':data'));

    }
    // ignore: empty_catches
    catch(e){}

    Node temp = NodeImpl(node['mUUID'], ':Users:' + storage.userUUID! + ':' + node['cUUID']+':data:metrics');
    temp.addValue(NodeValueImpl('name', node['name']));
    temp.addValue(NodeValueImpl('minValue', node['minValue']));
    temp.addValue(NodeValueImpl('maxValue', node['maxValue']));
    temp.addValue(NodeValueImpl('GEIGERvalue', node['GEIGERvalue']));
    temp.addValue(NodeValueImpl('valueType', node['valueType']));
    temp.addValue(NodeValueImpl('flag', node['flag']));
    temp.addValue(NodeValueImpl('threatsImpact', node['threatsImpact']));


    storage.controller.add(temp);


  }

 // print(storage.controller.get(':Users:' + storage.userUUID! + ':' + companyUUID +':data:metrics').getChildren());


}
